.. _user:

################
NumPy User Guide
################

This guide is intended as an introductory overview of NumPy and
explains how to install and make use of the most important features of
NumPy. For detailed reference documentation of the functions and
classes contained in the package, see the :ref:`reference`.

.. warning::

   This "User Guide" is still a work in progress; some of the material
   is not organized, and several aspects of NumPy are not yet covered
   in sufficient detail. However, we are continually working to
   improve the documentation.

   More documentation for NumPy can be found on the `numpy.org
   <http://www.numpy.org>`__ website.

.. toctree::
   :maxdepth: 2

   introduction
   basics
   performance
   misc
   c-info
